@@ -46,9 +46,10 @@ extern const QString defaultDownloadPath;
     X(AppTheme, "System") \
     X(BaseZoom, 1.0) \
     X(ParticipantsSide, false) \
-    X(HideSelf, false) \
+    X(HideSelf, true) \
     X(HideSpectators, false) \
     X(AutoUpdate, true) \
+    X(PluginAutoUpdate, false) \
     X(StartMinimized, false) \
     X(ShowChatviewHorizontally, true) \
     X(NeverShowMeAgain, false) \
@@ -56,12 +57,18 @@ extern const QString defaultDownloadPath;
     X(WindowState, QWindow::AutomaticVisibility) \
     X(EnableExperimentalSwarm, false) \
     X(LANG, "SYSTEM") \
+    X(PluginStoreEndpoint, "https://plugins.jami.net") \
     X(PositionShareDuration, 15) \
     X(PositionShareLimit, true) \
     X(FlipSelf, true) \
     X(ShowMardownOption, false) \
-    X(ShowSendOption, false)
-
+    X(ChatViewEnterIsNewLine, false) \
+    X(ShowSendOption, false) \
+    X(Donation2023VisibleDate, "2023-11-27 05:00") \
+    X(IsDonationVisible, true) \
+    X(Donation2023EndDate, "2024-01-31 00:00") \
+    X(EnablePtt, false) \
+    X(pttKey, 36)
 /*
  * A class to expose settings keys in both c++ and QML.
  * Note: this is using a non-constructable class instead of a
