@@ -25,7 +25,6 @@
 #include "appsettingsmanager.h"
 #include "connectivitymonitor.h"
 #include "systemtray.h"
-#include "previewengine.h"
 #include "videoprovider.h"
 
 #include <QAction>
@@ -106,7 +105,7 @@ ScreenInfo::onPhysicalDotsPerInchChanged()
 }
 
 MainApplication::MainApplication(int& argc, char** argv)
-    : QApplication(argc, argv)
+    : QApplication(argc, argv), isCleanupped(false)
 {
     const char* qtVersion = qVersion();
     qInfo() << "Using Qt runtime version:" << qtVersion;
@@ -130,12 +129,12 @@ MainApplication::init()
     // This 2-phase initialisation prevents ephemeral instances from
     // performing unnecessary tasks, like initializing the webengine.
     engine_.reset(new QQmlApplicationEngine(this));
-    connectivityMonitor_.reset(new ConnectivityMonitor(this));
-    settingsManager_.reset(new AppSettingsManager(this));
-    systemTray_.reset(new SystemTray(settingsManager_.get(), this));
-    previewEngine_.reset(new PreviewEngine(connectivityMonitor_.get(), this));
 
-    QObject::connect(settingsManager_.get(),
+    connectivityMonitor_ = new ConnectivityMonitor(this);
+    settingsManager_ = new AppSettingsManager(this);
+    systemTray_ = new SystemTray(settingsManager_, this);
+
+    QObject::connect(settingsManager_,
                      &AppSettingsManager::retranslate,
                      engine_.get(),
                      &QQmlApplicationEngine::retranslate);
@@ -148,8 +147,9 @@ MainApplication::init()
     setApplicationFont();
 
     initLrc(runOptions_[Option::UpdateUrl].toString(),
-            connectivityMonitor_.get(),
-            runOptions_[Option::Debug].toBool() && !runOptions_[Option::MuteJamid].toBool());
+            connectivityMonitor_,
+            runOptions_[Option::Debug].toBool(),
+            runOptions_[Option::MuteDaemon].toBool());
 
 #if defined(Q_OS_UNIX) && !defined(Q_OS_MACOS)
     using namespace Interfaces;
@@ -169,7 +169,7 @@ MainApplication::init()
     }
 #endif
 
-    connect(connectivityMonitor_.get(), &ConnectivityMonitor::connectivityChanged, this, [this] {
+    connect(connectivityMonitor_, &ConnectivityMonitor::connectivityChanged, this, [this] {
         QTimer::singleShot(500, this, [&]() { lrcInstance_->connectivityChanged(); });
     });
 
@@ -227,9 +227,11 @@ MainApplication::handleUriAction(const QString& arg)
 }
 
 void
-MainApplication::initLrc(const QString& downloadUrl, ConnectivityMonitor* cm, bool logDaemon)
+MainApplication::initLrc(const QString& downloadUrl,
+                         ConnectivityMonitor* cm,
+                         bool debugMode,
+                         bool muteDaemon)
 {
-    lrc::api::Lrc::cacheAvatars.store(false);
     /*
      * Init mainwindow and finish splash when mainwindow shows up.
      */
@@ -252,7 +254,8 @@ MainApplication::initLrc(const QString& downloadUrl, ConnectivityMonitor* cm, bo
         },
         downloadUrl,
         cm,
-        !logDaemon));
+        debugMode,
+        muteDaemon));
     lrcInstance_->subscribeToDebugReceived();
 }
 
@@ -318,7 +321,7 @@ MainApplication::parseArguments()
     runOptions_[Option::UpdateUrl] = parser.value(updateUrlOption);
 #endif
     runOptions_[Option::TerminationRequested] = parser.isSet(terminateOption);
-    runOptions_[Option::MuteJamid] = parser.isSet(muteDaemonOption);
+    runOptions_[Option::MuteDaemon] = parser.isSet(muteDaemonOption);
 }
 
 void
@@ -339,10 +342,10 @@ MainApplication::initQmlLayer()
 {
     // Expose custom types to the QML engine.
     Utils::registerTypes(engine_.get(),
-                         systemTray_.get(),
                          lrcInstance_.get(),
-                         settingsManager_.get(),
-                         previewEngine_.get(),
+                         systemTray_,
+                         settingsManager_,
+                         connectivityMonitor_,
                          &screenInfo_,
                          this);
 
@@ -373,7 +376,7 @@ MainApplication::initSystray()
     QAction* restoreAction = new QAction(tr("&Show Jami"), this);
     connect(restoreAction, &QAction::triggered, this, &MainApplication::restoreApp);
 
-    connect(systemTray_.get(),
+    connect(systemTray_,
             &QSystemTrayIcon::activated,
             this,
             [this](QSystemTrayIcon::ActivationReason reason) {
@@ -399,13 +402,16 @@ MainApplication::initSystray()
 void
 MainApplication::cleanup()
 {
-    QApplication::exit(0);
+    // In Qt 6.5, QApplication::exit(0) will signal aboutToQuit, and aboutToQuit is connected to cleanup
+    // TODO: delete cleanup.
+    if (!isCleanupped) {
+        isCleanupped = true;
+        QApplication::exit(0);
+    }
 }
 
-#ifdef Q_OS_MACOS
 void
 MainApplication::setEventFilter()
 {
     installEventFilter(this);
 }
-#endif
