@@ -22,23 +22,43 @@
 #include "pluginlistmodel.h"
 #include "pluginhandlerlistmodel.h"
 #include "pluginlistpreferencemodel.h"
+#include "appsettingsmanager.h"
+#include "pluginversionmanager.h"
+#include "pluginstorelistmodel.h"
 #include "preferenceitemlistmodel.h"
 
 #include <QObject>
 #include <QSortFilterProxyModel>
 #include <QString>
 
+class PluginVersionManager;
+class PluginStoreListModel;
+class AppSettingsManager;
+
 class PluginAdapter final : public QmlAdapterBase
 {
     Q_OBJECT
     QML_PROPERTY(int, callMediaHandlersListCount)
     QML_PROPERTY(int, chatHandlersListCount)
-    QML_PROPERTY(bool, isEnabled)
 
 public:
-    explicit PluginAdapter(LRCInstance* instance, QObject* parent = nullptr);
+    explicit PluginAdapter(LRCInstance* instance,
+                           AppSettingsManager* settingsManager,
+                           QObject* parent = nullptr,
+                           QString baseUrl = "https://plugins.jami.net");
     ~PluginAdapter() = default;
 
+    Q_INVOKABLE void getPluginsFromStore();
+    Q_INVOKABLE void getPluginDetails(const QString& pluginId);
+    Q_INVOKABLE void installRemotePlugin(const QString& pluginId);
+    Q_INVOKABLE QString baseUrl() const;
+    Q_INVOKABLE void checkVersionStatus(const QString& pluginId);
+    Q_INVOKABLE bool isAutoUpdaterEnabled();
+    Q_INVOKABLE void cancelDownload(const QString& pluginId);
+    Q_INVOKABLE void setAutoUpdate(bool state);
+    Q_INVOKABLE QString getIconUrl(const QString& pluginId) const;
+    Q_INVOKABLE QString getBackgroundImageUrl(const QString& pluginId) const;
+
 protected:
     Q_INVOKABLE QVariant getMediaHandlerSelectableModel(const QString& callId);
     Q_INVOKABLE QVariant getChatHandlerSelectableModel(const QString& accountId,
@@ -46,11 +66,20 @@ protected:
     Q_INVOKABLE QVariant getPluginPreferencesCategories(const QString& pluginId,
                                                         const QString& accountId,
                                                         bool removeLast = false);
+Q_SIGNALS:
+    void storeNotAvailable();
 
 private:
     void updateHandlersListCount();
 
+    PluginStoreListModel* pluginStoreListModel_;
+    PluginVersionManager* pluginVersionManager_;
+    PluginListModel* pluginListModel_;
+
     std::unique_ptr<PluginHandlerListModel> pluginHandlerListModel_;
 
+    LRCInstance* lrcInstance_;
+    AppSettingsManager* settingsManager_;
     std::mutex mtx_;
+    QString baseUrl_;
 };
